@@ -4,18 +4,36 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.06'; # VERSION
-our $DATE = '2014-07-02'; # DATE
+our $VERSION = '0.07'; # VERSION
+our $DATE = '2014-07-11'; # DATE
 
 our $_complete_program = sub {
     require Complete::Util;
     my %args = @_;
-    Complete::Util::mimic_shell_dir_completion(
-        Complete::Util::complete_program(
+
+    my $word = $args{word} // '';
+    my $completion;
+    my $is_path;
+    if ($word =~ m#/#) {
+        # if user specify path, e.g. ./foo, ../bar, or /usr/bin/ it means she
+        # wants to complete from filesystem. but note that complete_file()
+        # doesn't yet support ci=>1 option.
+        $is_path = 1;
+        $completion = Complete::Util::complete_file(
+            word => $word,
+            #ci   => 1, # convenience
+        );
+    } else {
+        $completion = Complete::Util::complete_program(
             word      => $args{word},
-            ci        => 1,
-        )
-      );
+            ci        => 1, # convenience
+        );
+    }
+
+    {
+        completion => $completion,
+        is_path    => $is_path,
+    };
 };
 
 1;
@@ -33,7 +51,7 @@ App::ProgUtils - Command line to manipulate programs in PATH
 
 =head1 VERSION
 
-This document describes version 0.06 of App::ProgUtils (from Perl distribution App-ProgUtils), released on 2014-07-02.
+This document describes version 0.07 of App::ProgUtils (from Perl distribution App-ProgUtils), released on 2014-07-11.
 
 =head1 SYNOPSIS
 
